@@ -4,7 +4,7 @@ from kindenty.model.DataDto import AccountTradeLogDto, RealMarketData, YieldData
     AssistDto, UserInvestmentDto, SellStatusDto
 from kindenty.model.DatabaseModel import Account, AccountPosition, RevokeOrderLog, \
     SharesQuotation, Strategy, TradeLog, OpenTradeLog, WorkerRegister, HistoryData, SharesQuotationHistory, \
-    TradeLogTest, YieldLog, AccountAssetsLog, ContrastLineData, LoginUser, UserInvestmentLog
+    TradeLogTest, YieldLog, AccountAssetsLog, ContrastLineData, LoginUser, UserInvestmentLog, License
 
 
 class AccountDao(BaseDao):
@@ -19,8 +19,9 @@ class AccountDao(BaseDao):
         "select id,account,category,account_type as accountType,balance,priority from account where account=':account' ",
         Account)
 
-    getById = SelectMethod("select id,account,category,account_type as accountType,balance,priority from account where id=:id ",
-                           Account)
+    getById = SelectMethod(
+        "select id,account,category,account_type as accountType,balance,priority from account where id=:id ",
+        Account)
 
     getAccountByTop1 = SelectMethod(
         "select id,category,account,account_type as accountType,balance,priority from account limit 1",
@@ -140,7 +141,8 @@ class SharesQuotationHistoryDao(BaseDao):
         from shares_quotation where date_format(now(),'%Y-%m-%d') > date_format(create_time,'%Y-%m-%d')""")
 
     selectCount = SelectMethod(
-        "select count(1) from shares_quotation_history where shares_code in (:sharesCodes) and last_price != 0 and date_format(create_time,'%Y-%m-%d') > ':startDate' and date_format(create_time,'%Y-%m-%d') <= ':endDate'", int)
+        "select count(1) from shares_quotation_history where shares_code in (:sharesCodes) and last_price != 0 and date_format(create_time,'%Y-%m-%d') > ':startDate' and date_format(create_time,'%Y-%m-%d') <= ':endDate'",
+        int)
 
     queryByLastpriceNotNone = QueryMethod("""
         select 0 as stopMark,shares_code as symbol,high_price as highPrice,last_price as lastPrice,
@@ -155,6 +157,8 @@ class StrategyDao(BaseDao):
 
     enableByIds = UpdateMethod("update strategy set enable=1, stop_time=null where id in (:ids)")
 
+    updateEnableByIds = UpdateMethod("update strategy set enable=':enable', stop_time=date_format(now(),'%Y-%m-%d %H:%i:%S') where id in (:ids)")
+
     queryIdByKey = QueryMethod("""
         select max(id) from strategy where concat(account_id,',',shares_code,',',version) in (:keys)
     """, int)
@@ -195,7 +199,7 @@ class StrategyDao(BaseDao):
                         and `type` in ('BUY','MARGIN_BUY','DEBIT_BUY') and status in(1,2,3) group by strategy_id) t on a.id=t.strategy_id
         left outer join (select strategy_id,sum(`buy_count`) as ct from trade_log where `type` in ('BUY','MARGIN_BUY','DEBIT_BUY') and status in(1,2,3) group by strategy_id)  b on a.id=b.strategy_id
         left outer join (select strategy_id,sum(`buy_count`) as ct from trade_log where `type` in ('SELL','DEBIT_SELL','MARGIN_SELL') and status in(0,1,2,3) group by strategy_id)  c on a.id=c.strategy_id
-        where shares_code = ':sharesCode' and (((b.ct-ifnull(c.ct,0))>0 and a.enable=0) or enable=1 or (a.version='1.4' and a.enable_sell=1)) order by t.minPrice""",
+        where shares_code = ':sharesCode' and (((b.ct-ifnull(c.ct,0))>0 and a.enable=0 and a.version!='1.5') or enable=1 or (a.version='1.4' and a.enable_sell=1)) order by t.minPrice""",
                                     Strategy)
 
     queryBySharesCodeAndAccountId = QueryMethod("""
@@ -272,7 +276,19 @@ class WorkerRegisterDao(BaseDao):
 class TradeLogDao(BaseDao):
     __mode__ = TradeLog
 
-    sumSellCountByStrategyId = SelectMethod("select ifnull(sum(buy_count),0) from trade_log where strategy_id=':strategyId' and `type` in ('SELL','DEBIT_SELL','MARGIN_SELL') and status in (2,3)", int)
+    sumSellCountByStrategyId = SelectMethod(
+        "select ifnull(sum(buy_count),0) from trade_log where strategy_id=':strategyId' and `type` in ('SELL','DEBIT_SELL','MARGIN_SELL') and status in (2,3)",
+        int)
+
+    sumBuyCountByStrategyId = SelectMethod(
+        "select ifnull(sum(buy_count),0) from trade_log where strategy_id=':strategyId' and `type` in ('BUY','MARGIN_BUY','DEBIT_BUY') and status in (2,3)",
+        int)
+
+    queryByStrategyIdAndPrice = QueryMethod("""
+        select id,strategy_id as strategyId,`type`,status,price,power,avg_price as avgPrice,`order_count` as orderCount,`buy_count` as buyCount,`time`,order_no as orderNo,buy_id as buyId,trade_time as tradeTime
+        from trade_log
+        where strategy_id=':strategyId' and `type` in ('BUY','MARGIN_BUY','DEBIT_BUY') and status in (2,3) and price=':price'
+    """, TradeLog)
 
     selectLatestByStrategyId = SelectMethod("""select id,strategy_id as strategyId,`type`,status,price,power,avg_price as avgPrice,`order_count` as orderCount,`buy_count` as buyCount,`time`,order_no as orderNo,buy_id as buyId,trade_time as tradeTime
         from trade_log
@@ -281,7 +297,9 @@ class TradeLogDao(BaseDao):
         limit 1
         """, TradeLog)
 
-    selectSellCountByStrategyId = SelectMethod("""select ifnull(sum(buy_count), 0) from trade_log where strategy_id=':strategyId' and status in (2, 3) and `type` in ('SELL','DEBIT_SELL','MARGIN_SELL')""", int)
+    selectSellCountByStrategyId = SelectMethod(
+        """select ifnull(sum(buy_count), 0) from trade_log where strategy_id=':strategyId' and status in (2, 3) and `type` in ('SELL','DEBIT_SELL','MARGIN_SELL')""",
+        int)
 
     selectOneByStrategyIdAndStatus = SelectMethod("""select id,strategy_id as strategyId,`type`,status,price,power,avg_price as avgPrice,`order_count` as orderCount,`buy_count` as buyCount,`time`,order_no as orderNo,buy_id as buyId,trade_time as tradeTime
         from trade_log
@@ -296,7 +314,15 @@ class TradeLogDao(BaseDao):
         limit 1
         """, TradeLog)
 
-    deleteBySharesCode = UpdateMethod("delete from trade_log where strategy_id in (select id from strategy where shares_code = ':sharesCode')")
+    selectByStrategyIdAndTypeAndStatus = SelectMethod("""select id,strategy_id as strategyId,`type`,status,price,power,avg_price as avgPrice,`order_count` as orderCount,`buy_count` as buyCount,`time`,order_no as orderNo,buy_id as buyId,trade_time as tradeTime
+            from trade_log
+            where strategy_id=':strategyId' and `type` in (:tradeType) and date_format(`time`,'%Y-%m-%d')=date_format(now(),'%Y-%m-%d') and status in (:status)
+            order by id desc 
+            limit 1
+            """, TradeLog)
+
+    deleteBySharesCode = UpdateMethod(
+        "delete from trade_log where strategy_id in (select id from strategy where shares_code = ':sharesCode')")
 
     cleanAll = UpdateMethod("delete from trade_log")
 
@@ -470,7 +496,9 @@ class AccountAssetsLogDao(BaseDao):
     clearSharesByDate = UpdateMethod(
         "update account_assets_log set shares=0 where `date` in (:dates) and account_id=:accountId")
 
-    updateAssetsAndNetValueById = UpdateMethod("update account_assets_log set assets=:assets, net_value=:netValue where id=:id")
+    updateAssetsAndNetValueById = UpdateMethod(
+        "update account_assets_log set assets=:assets, net_value=:netValue where id=:id")
+
 
 class ContrastLineDataDao(BaseDao):
     __mode__ = ContrastLineData
@@ -565,6 +593,15 @@ class UserInvestmentLogDao(BaseDao):
 
     selectCountByUserId = SelectMethod("select count(1) from user_investment_log where user_id=:userId", int)
 
+
+class LicenseDao(BaseDao):
+    __mode__ = License
+
+    selectOne = SelectMethod("select id,mac,license from license order by id desc limit 1", License)
+
+    updateLicense = UpdateMethod("update license set license=':license'")
+
+
 @transaction
 def test():
     accounts = [AccountPosition(accountId=1, sharesCode='123444', enableCount=1),
