@@ -15,6 +15,7 @@ log.info('root Path: %s' % os.getcwd())
 configParser = ConfigParser()
 configParser.read('conf/config.ini')
 host = configParser.get('database', 'host')
+port = configParser.get('database', 'port')
 user = configParser.get('database', 'userName')
 password = configParser.get('database', 'password')
 database = configParser.get('database', 'database')
@@ -22,4 +23,4 @@ driverName = configParser.get('database', 'driverName')
 type = DatabaseType[driverName]
 
 pool = Pool(maxActive=15, db_type=DatabaseType[driverName], host=host, user=user, password=password,
-            database=database, autocommit=True)
+            database=database, autocommit=True, port=int(port))
